timeintervaltools.scale_interval_offsets_by_rational
====================================================

.. autofunction:: abjad.tools.timeintervaltools.scale_interval_offsets_by_rational.scale_interval_offsets_by_rational
